"""fhs_xmltv_tools - xmltv tools versions."""

__version__ = "0.1.6"
__author__ = "Richard de Vos <rdevos72@gmail.com>"
__author_name__ = "Richard de Vos"
__author_email__ = "rdevos72@gmail.com"
__app_name__ = "fhs_xmltv_tools"
__project_name__ = "fhs-xmltv-tools"
__all__ = []
